@@ -586,8 +586,8 @@ class Client(object):
                              framework,
                              cos_output,
                              worker_resource,
+                             code_package_path,
                              ps_resource=None,
-                             code_package_path=None,
                              input_data_config=None,
                              worker_start_cmd=None,
                              ps_start_cmd=None,
@@ -610,12 +610,12 @@ class Client(object):
         :type cos_output:           str
         :param worker_resource:     Worker node configuration
         :type worker_resource:      :class:`tikit.models.ResourceConfigInfo`
-        :param ps_resource:         Resource of PS node
-        :type ps_resource:          :class:`tikit.models.ResourceConfigInfo`
         :param code_package_path:   COS information of the code
         :type code_package_path:    str
+        :param ps_resource:         Resource of PS node
+        :type ps_resource:          :class:`tikit.models.ResourceConfigInfo`
         :param input_data_config:   Input data information
-        :type input_data_config:    :class:`tikit.models.TrainingDataConfig`
+        :type input_data_config:    list of :class:`tikit.models.TrainingDataConfig`
         :param worker_start_cmd:    Worker node startup command
         :type worker_start_cmd:     str
         :param ps_start_cmd:        PS node startup command
@@ -687,6 +687,7 @@ class Client(object):
                 ps_info.Memory = ps_resource.Memory
                 ps_info.GpuType = ps_resource.GpuType
                 ps_info.Gpu = ps_resource.Gpu
+                ps_info.InstanceType = ps_resource.InstanceType
                 req.ResourceConfigInfos.append(ps_info)
 
             req.Output = self.parse_cos_info(cos_output)
@@ -694,22 +695,9 @@ class Client(object):
             req.CodePackagePath = self.parse_cos_info(code_package_path) if code_package_path else None
             req.StartCmdInfo = models.StartCmdInfo()
             req.StartCmdInfo.WorkerStartCmd = worker_start_cmd
-            req.StartCmdInfo.PStartCmd = ps_start_cmd
+            req.StartCmdInfo.PsStartCmd = ps_start_cmd
 
-            req.DataSource = input_data_config.DataSource
-            req.DataConfigs = []
-            if req.DataSource == "DATASET":
-                for dataset_id in input_data_config.DataConfigDict:
-                    data_config = models.DataConfig()
-                    data_config.MappingPath = input_data_config.DataConfigDict[dataset_id]
-                    data_config.Id = dataset_id
-                    req.DataConfigs.append(data_config)
-            if req.DataSource == "COS":
-                for cos_str in input_data_config.DataConfigDict:
-                    data_config = models.DataConfig()
-                    data_config.MappingPath = input_data_config.DataConfigDict[cos_str]
-                    data_config.StorageDataPath = self.parse_cos_info(cos_str)
-                    req.DataConfigs.append(data_config)
+            req.DataConfigs, req.DataSource = self._parse_training_task_input_data(input_data_config)
 
             req.TuningParameters = json.dumps(tuning_parameters_dict)
             req.Remark = remark
@@ -726,6 +714,49 @@ class Client(object):
         except TencentCloudSDKException as err:
             raise
 
+    def _parse_training_task_input_data(self, input_data_config):
+        data_configs = []
+        data_type = ""  # 兼容旧版本
+        if not isinstance(input_data_config, list):
+            # 兼容旧版本的处理
+            if input_data_config.DataSource == "DATASET":
+                for dataset_id in input_data_config.DataConfigDict:
+                    data_config = models.DataConfig()
+                    data_config.DataSourceType = input_data_config.DataSource
+                    data_config.MappingPath = input_data_config.DataConfigDict[dataset_id]
+                    data_config.DataSetSource = models.DataSetConfig()
+                    data_config.DataSetSource.Id = dataset_id
+                    data_configs.append(data_config)
+            if input_data_config.DataSource == "COS":
+                for cos_str in input_data_config.DataConfigDict:
+                    data_config = models.DataConfig()
+                    data_config.DataSourceType = input_data_config.DataSource
+                    data_config.MappingPath = input_data_config.DataConfigDict[cos_str]
+                    data_config.COSSource = self.parse_cos_info(cos_str)
+                    data_configs.append(data_config)
+            return data_configs, input_data_config.DataSource
+
+        for input_data_item in input_data_config:
+            data_config = models.DataConfig()
+            data_config.DataSourceType = input_data_item.DataSource
+            data_config.MappingPath = input_data_item.TargetPath
+            if input_data_item.DataSource == "COS":
+                data_config.COSSource = self.parse_cos_info(input_data_item.CosStr)
+            elif input_data_item.DataSource == "DATASET":
+                data_config.DataSetSource = models.DataSetConfig()
+                data_config.DataSetSource.Id = input_data_item.DatasetId
+            elif input_data_item.DataSource == "CFS":
+                data_config.CFSSource = models.CFSConfig()
+                data_config.CFSSource.Id = input_data_item.CfsId
+                data_config.CFSSource.Path = input_data_item.CfsPath
+            elif input_data_item.DataSource == "HDFS":
+                data_config.HDFSSource = models.HDFSConfig()
+                data_config.HDFSSource.Id = input_data_item.HdfsId
+                data_config.HDFSSource.Path = input_data_item.HdfsPath
+            data_configs.append(data_config)
+            data_type = input_data_item.DataSource
+        return data_configs, data_type
+
     def stop_training_task(self, task_id):
         """Stop a training task
 
@@ -744,18 +775,23 @@ class Client(object):
         """Get the platform's built-in training frameworks
 
         :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingFrameworksResponse`
-        Result of "print" function is as follows:
-        +------------+-------------------------+-------------------------+
-        |  Framework name | Framework Version  |       Training mode     |
-        +------------+-------------------------+-------------------------+
-        | TENSORFLOW |      1.15-py3.6-cpu     | PS_WORKER, MPI, HOROVOD |
-        |            | 1.15-py3.6-cuda10.0-gpu |                         |
-        |            |      2.4-py3.6-cpu      |                         |
-        |            |  2.4-py3.6-cuda11.0-gpu |                         |
-        |  PYTORCH   |  1.9-py3.6-cuda11.1-gpu |    DDP, MPI, HOROVOD    |
-        |  PYSPARK   |     2.4.5-py3.6-cpu     |                         |
-        |   LIGHT    |  3.0-py3.6-cuda11.0-gpu |    DDP, MPI, HOROVOD    |
-        +------------+-------------------------+-------------------------+
+        print返回的结果，输出如下：
+        +------------+-------------------------------------------+-------------------------+
+        | Framework name   | Framework Version                   | Training mode           |
+        +------------+-------------------------------------------+-------------------------+
+        | TI_ACC     | 1.0.0-torch1.7.1-py3.6-cuda10.1-gpu       | DDP                     |
+        | TI_ACC     | 1.0.0-torch1.8.1-py3.6-cuda10.2-gpu       | DDP                     |
+        | TI_ACC     | 1.0.0-torch1.9.0-py3.8-cuda11.1-gpu       | DDP                     |
+        | TI_ACC     | 1.0.0-tensorflow1.15.5-py3.6-cuda10.0-gpu | PS_WORKER               |
+        | TENSORFLOW | 1.15-py3.6-cpu                            | PS_WORKER, MPI, HOROVOD |
+        | TENSORFLOW | 1.15-py3.6-cuda10.0-gpu                   | PS_WORKER, MPI, HOROVOD |
+        | TENSORFLOW | 2.4-py3.6-cpu                             | PS_WORKER, MPI, HOROVOD |
+        | TENSORFLOW | 2.4-py3.6-cuda11.0-gpu                    | PS_WORKER, MPI, HOROVOD |
+        | PYTORCH    | 1.9-py3.6-cuda11.1-gpu                    | DDP, MPI, HOROVOD       |
+        | SPARK      | 2.4.5-cpu                                 | SPARK                   |
+        | PYSPARK    | 2.4.5-py3.6-cpu                           | SPARK                   |
+        | LIGHT      | 3.1.3-py3.6-cuda11.0-gpu                  | DDP, MPI, HOROVOD       |
+        +------------+-------------------------------------------+-------------------------+
         """
         try:
             req = models.DescribeTrainingFrameworksRequest()
